Module server_reflection_request

Module server_reflection_request 

Enums

MessageRequest
To use reflection service, the client should set one of the following fields in message_request. The server distinguishes requests by their defined field and then handles them using corresponding methods.
MessageRequestView