pub struct ServiceResponse {
pub name: String,
/* private fields */
}Expand description
The information of a single service used by ListServiceResponse to answer list_services request.
Fields
name: StringFull name of a registered service, including its package name. The format is <package>.<service>
Field 1: name
Implementations